==> kubernetes-model-extensions-5.9.0-sources.jar: io/fabric8/kubernetes/api/model/extensions/IngressTLSFluent.java <==
package io.fabric8.kubernetes.api.model.extensions;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface IngressTLSFluent<A extends io.fabric8.kubernetes.api.model.extensions.IngressTLSFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToHosts(java.lang.Integer index,java.lang.String item);
  public A setToHosts(java.lang.Integer index,java.lang.String item);
  public A addToHosts(java.lang.String... items);
  public A addAllToHosts(java.util.Collection<java.lang.String> items);
  public A removeFromHosts(java.lang.String... items);
  public A removeAllFromHosts(java.util.Collection<java.lang.String> items);
  public java.util.List<java.lang.String> getHosts();
  public java.lang.String getHost(java.lang.Integer index);
  public java.lang.String getFirstHost();
  public java.lang.String getLastHost();
  public java.lang.String getMatchingHost(java.util.function.Predicate<java.lang.String> predicate);
  public java.lang.Boolean hasMatchingHost(java.util.function.Predicate<java.lang.String> predicate);
  public A withHosts(java.util.List<java.lang.String> hosts);
  public A withHosts(java.lang.String... hosts);
  public java.lang.Boolean hasHosts();
  public A addNewHost(java.lang.String arg0);
  public java.lang.String getSecretName();
  public A withSecretName(java.lang.String secretName);
  public java.lang.Boolean hasSecretName();
  
  /**
   * Method is deprecated. use withSecretName instead.
   */
  @java.lang.Deprecated
  public A withNewSecretName(java.lang.String arg0);
  
}

==> kubernetes-model-extensions-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/extensions/IngressTLSFluent.java <==
package io.fabric8.kubernetes.api.model.extensions;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface IngressTLSFluent<A extends io.fabric8.kubernetes.api.model.extensions.IngressTLSFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToHosts(java.lang.Integer index,java.lang.String item);
  public A setToHosts(java.lang.Integer index,java.lang.String item);
  public A addToHosts(java.lang.String... items);
  public A addAllToHosts(java.util.Collection<java.lang.String> items);
  public A removeFromHosts(java.lang.String... items);
  public A removeAllFromHosts(java.util.Collection<java.lang.String> items);
  public java.util.List<java.lang.String> getHosts();
  public java.lang.String getHost(java.lang.Integer index);
  public java.lang.String getFirstHost();
  public java.lang.String getLastHost();
  public java.lang.String getMatchingHost(java.util.function.Predicate<java.lang.String> predicate);
  public java.lang.Boolean hasMatchingHost(java.util.function.Predicate<java.lang.String> predicate);
  public A withHosts(java.util.List<java.lang.String> hosts);
  public A withHosts(java.lang.String... hosts);
  public java.lang.Boolean hasHosts();
  public A addNewHost(java.lang.String arg0);
  public java.lang.String getSecretName();
  public A withSecretName(java.lang.String secretName);
  public java.lang.Boolean hasSecretName();
  
  /**
   * Method is deprecated. use withSecretName instead.
   */
  @java.lang.Deprecated
  public A withNewSecretName(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  
}
